.. _pipeline-examples:

Pipeline examples
=================

For your convenience, find below some example pipelines to be used with the
corresponding OpenStack Compute version. These are to be **added** into your
``/etc/nova/api-paste.ini`` configuration file.

.. toctree::

    juno
    kilo
    liberty
    mitaka
    newton
